# Magurn

## A python application which scrapes data from torrent indexers and finds the best torrent magnet for the specific search term.

* Included an EXE file to run directly for windows.

Requirements-
```
pip install requests bs4 pyperclip
```

- If torrent sites are blocked in your region use a VPN or Proxy else the application won't work.
